==> level1c4pps-0.2.29.tar.gz: level1c4pps-0.2.29/CHANGELOG.md <==
## Version <RELEASE_VERSION> (2022/03/03)

### Issues Closed

* [Issue 68](https://github.com/foua-pps/level1c4pps/issues/68) - FOr AVHRR data missing ch3a/b gives no image5 dataset

In this release 1 issue was closed.

## Version <v.0.2.28> (2022/01/27)

### Issues Closed

* [Issue 65](https://github.com/foua-pps/level1c4pps/issues/65) - Missmatch in orbitnumber in netcdf filename and posttroll message tag 'orbit_number' VIIRS when using level 1c runner in pytroll pps runner
* [Issue 51](https://github.com/foua-pps/level1c4pps/issues/51) - Seviri2pps fails with h5netcdf backend

In this release 4 issues were closed.

### Pull Requests Merged

#### Bugs fixed

In this release 1 pull request was closed.

## Version <v0.2.27> (2021/06/21)

### Issues Closed

* [Issue 63](https://github.com/foua-pps/level1c4pps/issues/63) - New satpy wavelength attribute format not supported by PPS-2021
* [Issue 40](https://github.com/foua-pps/level1c4pps/issues/40) - Use satpy to rotate SEVIRI image

In this release 2 issues were closed.

### Pull Requests Merged

#### Bugs fixed

* [PR 61](https://github.com/foua-pps/level1c4pps/pull/61) - Updates for next pypi release

In this release 1 pull request was closed.

###############################################################################
## Version <v0.2.26> (2021/05/20)


### Pull Requests Merged

#### Features addeded

* [PR 60](https://github.com/foua-pps/level1c4pps/pull/60) - Add support for github-ci and prepare releasing on PyPi

In this release 1 pull request was closed.

###############################################################################

## Version <v0.2.25> (2021/05/19)

==> level1c4pps-0.2.31.tar.gz: level1c4pps-0.2.31/CHANGELOG.md <==

## Version <v.0.2.31> (2023/01/19)


### Pull Requests Merged

* [PR 73](https://github.com/foua-pps/level1c4pps/pull/73) - Fixing channel unit, by [@ninahakansson](https://github.com/ninahakansson)
* [PR 72](https://github.com/foua-pps/level1c4pps/pull/72) - Read also channel 7.3µm MERSI2, by [@ninahakansson](https://github.com/ninahakansson)
* [PR 71](https://github.com/foua-pps/level1c4pps/pull/71) - Add clipping for SEVIRI calibration coefficients, by [@sfinkens](https://github.com/sfinkens)

In this release 3 pull requests were closed.

## Version <v.0.2.30> (2022/04/29)


### Pull Requests Merged

* [PR 70](https://github.com/foua-pps/level1c4pps/pull/70) - Usage ch r22, by [@shornqui](https://github.com/shornqui)

In this release 1 pull request was closed.


## Version <v.0.2.29> (2022/03/03)

### Issues Closed

* [Issue 68](https://github.com/foua-pps/level1c4pps/issues/68) - FOr AVHRR data missing ch3a/b gives no image5 dataset

In this release 1 issue was closed.

## Version <v.0.2.28> (2022/01/27)

### Issues Closed

* [Issue 65](https://github.com/foua-pps/level1c4pps/issues/65) - Missmatch in orbitnumber in netcdf filename and posttroll message tag 'orbit_number' VIIRS when using level 1c runner in pytroll pps runner
* [Issue 51](https://github.com/foua-pps/level1c4pps/issues/51) - Seviri2pps fails with h5netcdf backend

In this release 4 issues were closed.

### Pull Requests Merged

#### Bugs fixed

In this release 1 pull request was closed.

## Version <v0.2.27> (2021/06/21)

### Issues Closed

* [Issue 63](https://github.com/foua-pps/level1c4pps/issues/63) - New satpy wavelength attribute format not supported by PPS-2021
* [Issue 40](https://github.com/foua-pps/level1c4pps/issues/40) - Use satpy to rotate SEVIRI image

In this release 2 issues were closed.

### Pull Requests Merged

#### Bugs fixed

* [PR 61](https://github.com/foua-pps/level1c4pps/pull/61) - Updates for next pypi release

In this release 1 pull request was closed.

###############################################################################
## Version <v0.2.26> (2021/05/20)


### Pull Requests Merged

#### Features addeded

* [PR 60](https://github.com/foua-pps/level1c4pps/pull/60) - Add support for github-ci and prepare releasing on PyPi

In this release 1 pull request was closed.

###############################################################################

## Version <v0.2.25> (2021/05/19)
